# for python 3.x use 'tkinter' rather than 'Tkinter'

from tkinter import * 
import datetime
import math
from tkinter.font import *
import time

class App(object):
    def __init__(self, root):

        self.frame_clock = Frame(root)
        self.root=root
        frame_time = LabelFrame(root, text="Time Settings")
        frame_alarm = LabelFrame(root, text="Alarm")    
        frame_appearance = LabelFrame(root, text="Alpha")     

        self.frame_clock.pack(expand=1,side=LEFT, fill=BOTH, padx=10, pady=10)
        frame_time.pack(fill=X, ipadx=5, ipady=5, padx=5, pady=5)
        frame_alarm.pack(fill=X, ipadx=19, ipady=5, padx=5, pady=5)
        frame_appearance.pack(fill=X, ipadx=19, ipady=5, padx=5, pady=5)
        
        tmz_var = StringVar()
        tmz_var.set("UTC+01:00")
        
        self.sec_var = IntVar()
        self.sec_var.set(1)
        ed_var = IntVar()
        ed_var.set(1)

        ### DRAW CLOCK    

        self.can_width = 180      # sirka canvasu
        self.can_height = 180     # vyska canvasu
        self.line_width = 3       # sirka ciferniku
        self.hour_len = 0.7       # delka hodinove rucicky
        self.minute_len = 0.8     # delka minutove rucicky
        self.second_len = 0.9     # delka sekundove rucicky
        self.hour_width = 3       # sirka hodinove rucicky
        self.minute_width = 2     # sirka minutove rucicky
        self.second_width = 1     # sirka sekundove rucicky

        self.c = Canvas(self.frame_clock)
       
        self.cc = self.c.create_oval(self.line_width, self.line_width, self.can_width-self.line_width, self.can_height-self.line_width, width=self.line_width)
        self.hh = self.c.create_line(self.can_width/2, self.can_height/2, self.can_width/2, self.can_height/2 ,   width = self.hour_width)
        self.mh = self.c.create_line(self.can_width/2, self.can_height/2, self.can_width/2, self.can_height/2 , width = self.minute_width)
        self.sh = self.c.create_line(self.can_width/2, self.can_height/2, self.can_width/2, self.can_height/2 , width = self.second_width)

        self.lbl_date = Label(self.frame_clock, font = Font(size=12, weight="bold"))

        self.c.pack(expand =1, fill=BOTH)
        self.c.bind("<Configure>", self.resize)
        self.lbl_date.pack(pady=15)


        ### DRAW TIME SETTINGS

        frame_time_zone = Frame(frame_time)
      
        ### DRAW ALARM

        frame_alarm_time = Frame(frame_alarm)
      


        self.draw_current_time()
        self.timer_update()
        
        
    def scgetval(self, val):
        self.root.wm_attributes('-alpha', 1.0-float(val)/100.0)
    
    def timer_update(self):
        self.frame_clock.after(1000, self.timer_update)
        self.draw_current_time()

    def resize(self,event):
        #print '(%d, %d)' % (event.width, event.height)
        self.can_width=event.width
        self.can_height=event.height
        self.draw_current_time()
        
        
    def draw_current_time(self):
        dt = datetime.datetime.now()
                  
        xh = 0
        yh = 0
        
        xm = self.can_width/2 * self.minute_len * math.cos( float(dt.minute-15) * math.pi / 30.0)
        ym = self.can_height/2 * self.minute_len * math.sin( float(dt.minute-15) * math.pi / 30.0)   

        xs = self.can_width/2 * self.second_len * math.cos(float(dt.second-15) * math.pi / 30.0)
        ys = self.can_height/2 * self.second_len * math.sin(float(dt.second-15) * math.pi / 30.0)      

        self.c.coords(self.cc, self.line_width, self.line_width, self.can_width-self.line_width, self.can_height-self.line_width)
        self.c.coords(self.hh, self.can_width/2, self.can_height/2, self.can_width/2 + xh, self.can_height/2 + yh)
        self.c.coords(self.mh, self.can_width/2, self.can_height/2, self.can_width/2 + xm, self.can_height/2 + ym)
        
        
        if(self.sec_var.get()): self.c.coords(self.sh, self.can_width/2, self.can_height/2, self.can_width/2 + xs, self.can_height/2 + ys)
        else: self.c.coords(self.sh, self.can_width/2, self.can_height/2, self.can_width/2, self.can_height/2)

        t = "%d.%d.%d  %02d:%02d:%02d" % (dt.day, dt.month, dt.year, dt.hour, dt.minute, dt.second)
        self.lbl_date.config(text=t)

        
    def draw_alarm_line(self):
        th = (float(self.ent_hour.get())-3.0 + float(self.ent_min.get())/60.0) * math.pi / 6.0
        xh =  self.can_width/2 *  self.hour_len *  math.cos(th)
        yh =  self.can_height/2 * self.hour_len *  math.sin(th)      
        self.ala = self.c.create_line(self.can_width/2, self.can_height/2, self.can_width/2 + xh, self.can_height/2 + yh, width = 2, fill="red")

        self.ent_hour.config(state=DISABLED)
        self.ent_min.config(state=DISABLED)
        self.ent_sec.config(state=DISABLED)
        self.ed_ala.config(state=DISABLED)
        self.btn1_ala.config(state=DISABLED)
        self.btn2_ala.config(state=NORMAL)

    def reset_alarm_line(self):
        self.c.delete(self.ala)

        self.ent_hour.config(state=NORMAL)
        self.ent_min.config(state=NORMAL)
        self.ent_sec.config(state=NORMAL)
        self.ed_ala.config(state=NORMAL)
        self.btn2_ala.config(state=DISABLED)
        self.btn1_ala.config(state=NORMAL)


def main(): 
    root= Tk() 
    root.wm_title("Clock")
    #root.resizable(False, False)
    app = App(root)
    root.mainloop() 

if __name__=='__main__': 
  main() 

